==> agr-center-domain-3.1.0-CLOUD-DEV-20230731.090500-43-sources.jar: com/tydic/dyc/agr/model/agrchange/sub/AgrItemChng.java <==
package com.tydic.dyc.agr.model.agrchange.sub;

import lombok.Data;
import java.io.Serializable;
import com.tydic.dyc.agr.model.agrchange.sub.AgrItemLadderPriceChng;
import com.tydic.dyc.agr.model.agrchange.sub.AgrItemExtChng;
import java.math.BigDecimal;
import java.util.List;

/**
 * 描述：null 
 * 
 * @author auto_gen
 * @date 2023-04-23 19:08
 **/
@Data
public class AgrItemChng implements Serializable {
	private static final long serialVersionUID =  2483088746205293626L;

	/**
	 * 明细变更类型
	 */
	private Integer itemChngType;
	/**
	 * 协议明细状态
	 */
	private Integer agrSkuStatus;
	/**
	 * 物料ID
	 */
	private String materialId;
	/**
	 * 物料编码
	 */
	private String materialCode;
	/**
	 * 物料名称
	 */
	private String materialName;
	/**
	 * 型号
	 */
	private String model;
	/**
	 * 图号
	 */
	private String figure;
	/**
	 * 规格
	 */
	private String spec;
	/**
	 * 材质
	 */
	private String texture;
	/**
	 * 品牌ID
	 */
	private Long brandId;
	/**
	 * 品牌
	 */
	private String brandName;
	/**
	 * 是否成品油
	 */
	private Integer whetherOil;
	/**
	 * 生产厂家
	 */
	private String manufacturer;
	/**
	 * 计量单位ID
	 */
	private Long measureId;
	/**
	 * 计量单位
	 */
	private String measureName;
	/**
	 * 数量
	 */
	private BigDecimal buyNumber;
	/**
	 * 最小起订量
	 */
	private BigDecimal moq;
	/**
	 * 采购单价
	 */
	private BigDecimal buyPrice;
	/**
	 * 采购总价
	 */
	private BigDecimal buyPriceSum;
	/**
	 * 加价比率（%）
	 */
	private BigDecimal markupRate;
	/**
	 * 原价
	 */
	private Long oldPrice;
	/**
	 * 销售单价
	 */
	private BigDecimal salePrice;
	/**
	 * 销售总价
	 */
	private BigDecimal salePriceSum;
	/**
	 * 折扣率
	 */
	private BigDecimal discountRate;
	/**
	 * 原折扣率
	 */
	private BigDecimal oldDiscountRate;
	/**
	 * 市场价
	 */
	private BigDecimal marketPrice;
	/**
	 * 协议价
	 */
	private BigDecimal agrPrice;
	/**
	 * 阶梯价组ID
	 */
	private Long ladderPriceId;
	/**
	 * 管理单位ID
	 */
	private Long managementOrgId;
	/**
	 * 供货商ID
	 */
	private Long supplierId;
	/**
	 * 供货商名称
	 */
	private String supplierName;
	/**
	 * 供货周期
	 */
	private Integer supplyCycle;
	/**
	 * 分类ID
	 */
	private String catalogId;
	/**
	 * 分类编码
	 */
	private String catalogCode;
	/**
	 * 分类名称
	 */
	private String catalogName;
	/**
	 * 税收分类编码
	 */
	private String taxCatalog;
	/**
	 * 质保等级
	 */
	private String warrantyLevel;
	/**
	 * 税率
	 */
	private BigDecimal taxRate;
	/**
	 * 商品铺货标识
	 */
	private Integer skuSymbol;
	/**
	 * 备注
	 */
	private String remark;
	/**
	 * 协议明细变更ID
	 */
	private Long agrItemChngId;
	/**
	 * 协议明细变更ID集合
	 */
	private List<Long> agrItemChngIds;
	/**
	 * 协议明细ID
	 */
	private Long agrItemId;
	/**
	 * 协议明细阶梯价变更
	 */
	private List<AgrItemLadderPriceChng> agrItemLadderPriceChng;
	/**
	 * 协议明细扩展变更
	 */
	private List<AgrItemExtChng> agrItemExtChng;
	/**
	 * 商品类型ID
	 */
	private Long commodityTypeId;
	/**
	 * 商品类型名称
	 */
	private String commodityTypeName;
	/**
	 * 排序
	 */
	private String orderBy;

}

==> agr-center-domain-3.2.2-CLOUD-DEV-20241022.082438-3-sources.jar: com/tydic/dyc/agr/model/agrchange/sub/AgrItemChng.java <==
package com.tydic.dyc.agr.model.agrchange.sub;

import lombok.Data;
import java.io.Serializable;
import com.tydic.dyc.agr.model.agrchange.sub.AgrItemLadderPriceChng;
import com.tydic.dyc.agr.model.agrchange.sub.AgrItemExtChng;
import java.math.BigDecimal;
import java.util.List;

/**
 * 描述：null 
 * 
 * @author auto_gen
 * @date 2023-08-04 17:46
 **/
@Data
public class AgrItemChng implements Serializable {
	private static final long serialVersionUID =  3599825948530307441L;

	/**
	 * 明细变更类型
	 */
	private Integer itemChngType;
	/**
	 * 协议明细状态
	 */
	private Integer agrSkuStatus;
	/**
	 * 物料ID
	 */
	private String materialId;
	/**
	 * 物料编码
	 */
	private String materialCode;
	/**
	 * 物料名称
	 */
	private String materialName;
	/**
	 * 型号
	 */
	private String model;
	/**
	 * 图号
	 */
	private String figure;
	/**
	 * 规格
	 */
	private String spec;
	/**
	 * 材质
	 */
	private String texture;
	/**
	 * 品牌ID
	 */
	private Long brandId;
	/**
	 * 品牌
	 */
	private String brandName;
	/**
	 * 是否成品油
	 */
	private Integer whetherOil;
	/**
	 * 生产厂家
	 */
	private String manufacturer;
	/**
	 * 计量单位ID
	 */
	private Long measureId;
	/**
	 * 计量单位
	 */
	private String measureName;
	/**
	 * 数量
	 */
	private BigDecimal buyNumber;
	/**
	 * 最小起订量
	 */
	private BigDecimal moq;
	/**
	 * 采购单价
	 */
	private BigDecimal buyPrice;
	/**
	 * 采购总价
	 */
	private BigDecimal buyPriceSum;
	/**
	 * 加价比率（%）
	 */
	private BigDecimal markupRate;
	/**
	 * 原价
	 */
	private Long oldPrice;
	/**
	 * 销售单价
	 */
	private BigDecimal salePrice;
	/**
	 * 销售总价
	 */
	private BigDecimal salePriceSum;
	/**
	 * 折扣率
	 */
	private BigDecimal discountRate;
	/**
	 * 原折扣率
	 */
	private BigDecimal oldDiscountRate;
	/**
	 * 市场价
	 */
	private BigDecimal marketPrice;
	/**
	 * 协议价
	 */
	private BigDecimal agrPrice;
	/**
	 * 阶梯价组ID
	 */
	private Long ladderPriceId;
	/**
	 * 管理单位ID
	 */
	private String managementOrgId;
	/**
	 * 供货商ID
	 */
	private Long supplierId;
	/**
	 * 供货商名称
	 */
	private String supplierName;
	/**
	 * 供货周期
	 */
	private Integer supplyCycle;
	/**
	 * 分类ID
	 */
	private String catalogId;
	/**
	 * 分类编码
	 */
	private String catalogCode;
	/**
	 * 分类名称
	 */
	private String catalogName;
	/**
	 * 税收分类编码
	 */
	private String taxCatalog;
	/**
	 * 质保等级
	 */
	private String warrantyLevel;
	/**
	 * 税率
	 */
	private BigDecimal taxRate;
	/**
	 * 商品铺货标识
	 */
	private Integer skuSymbol;
	/**
	 * 备注
	 */
	private String remark;
	/**
	 * 协议明细变更ID
	 */
	private Long agrItemChngId;
	/**
	 * 协议明细变更ID集合
	 */
	private List<Long> agrItemChngIds;
	/**
	 * 协议明细ID
	 */
	private Long agrItemId;
	/**
	 * 协议明细阶梯价变更
	 */
	private List<AgrItemLadderPriceChng> agrItemLadderPriceChng;
	/**
	 * 协议明细扩展变更
	 */
	private List<AgrItemExtChng> agrItemExtChng;
	/**
	 * 商品类型ID
	 */
	private Long commodityTypeId;
	/**
	 * 商品类型名称
	 */
	private String commodityTypeName;
	/**
	 * 排序
	 */
	private String orderBy;

}
